<?php

// SRC is defined as the path to the src/ directory from public/

/*
	============================================================
	Libraries
	============================================================
*/
require_once SRC . '/helpers.php';
require_once SRC . '/components.php';
require_once SRC . '/enums.php';

/*
	============================================================
	PHP Sessions
	============================================================
*/
session_start();

/*
	============================================================
	Autoloading
	============================================================
*/
define('CLASS_MAP', [
	'Database'     => '/database.php',
	'Router'       => '/router.php',
	'User'         => '/models/user.php',
	'Character'    => '/models/character.php',
	'Wallet'       => '/models/wallet.php',
	'Session'      => '/models/session.php',
	'Actions\Auth' => '/actions/auth.php',
]);

spl_autoload_register(function (string $class) {
	if (array_key_exists($class, CLASS_MAP)) require_once SRC . CLASS_MAP[$class];
});

// Track the start time of the request
define('START_TIME', microtime(true));

/*
	============================================================
	.ENV
	============================================================
*/
env_load(SRC . '/../.env');

if (env('debug', false)) {
	ini_set('display_errors', '1');
	ini_set('display_startup_errors', '1');
	error_reporting(E_ALL);
}

/*
	============================================================
	CSRF
	============================================================
*/
csrf(); // generate a CSRF token, or retrieve the current token

// error any request that fails CSRF on these methods
if (in_array($_SERVER['REQUEST_METHOD'], ['POST', 'PUT', 'PATCH', 'DELETE'])) {
	$csrf = $_POST['csrf'] ?? $_SERVER['HTTP_X_CSRF'] ?? '';
	if (!hash_equals($_SESSION['csrf'] ?? '', $csrf)) error_response(418);
}

/*
	============================================================
	Global State
	============================================================
*/
$GLOBALS['databases'] = []; // database interfaces

// all relevant state to handling requests
$GLOBALS['state'] = [
	'logged_in' => isset($_SESSION['user']) || validate_session()
];
